# CuPID (Python Library)

This is a library for python used for downloading and working with CuPID data.

Install via pip:
```
pip install cupid
```
Usage Examples:
```
Examples
```

If you make use of this code, please cite the mission paper:

```
Citation to come
```
